@@ -4,3 +4,5 @@ pub use set_status::set_status;
 mod errors;
 mod read_lint_config;
 mod set_status;
+#[cfg(test)]
+mod set_status_test;
